@@ -4,10 +4,12 @@ from MSApi.Template import Template
 from MSApi.ObjectMS import ObjectMS
 
 from MSApi.mixin.GenListMixin import GenerateListMixin
+from MSApi.mixin.NameMixin import NameMixin
 
 
 class Assortment(ObjectMS,
-                 GenerateListMixin):
+                 GenerateListMixin,
+                 NameMixin):
     _type_name = 'assortment'
 
     @classmethod
