@@ -1,5 +1,8 @@
 import logging
 
+from requests import Session
+from requests.adapters import HTTPAdapter, Retry
+
 from MSApi.exceptions import *
 from MSApi.properties import *
 import requests
@@ -40,12 +43,12 @@ class Authorizer:
     token = None
 
     @classmethod
-    def login(cls, login: str, password: str):
+    def login(cls, login: str, password: str, session=Session()):
         import base64
         auch_base64 = base64.b64encode(f"{login}:{password}".encode('utf-8')).decode('utf-8')
 
-        response = requests.post(f"{ms_url}/security/token",
-                                 headers={"Authorization": f"Basic {auch_base64}"})
+        response = session.post(f"{ms_url}/security/token",
+                                headers={"Authorization": f"Basic {auch_base64}"})
         error_handler(response, 201)
         cls.token = str(response.json()["access_token"])
 
@@ -54,7 +57,16 @@ class Authorizer:
         return cls.token is not None
 
 
+def _create_session():
+    session = Session()
+    session.mount('https://',
+                  HTTPAdapter(max_retries=Retry(total=10, status_forcelist=[500, 503])))
+    return session
+
+
 class MSLowApi:
+
+    __session = _create_session()
     __authorizer = Authorizer()
 
     @classmethod
@@ -63,7 +75,7 @@ class MSLowApi:
 
     @classmethod
     def login(cls, login: str, password: str):
-        cls.__authorizer.login(login, password)
+        cls.__authorizer.login(login, password, cls.__session)
 
     @classmethod
     def check_login(cls, f):
@@ -82,10 +94,10 @@ class MSLowApi:
     def auch_post(cls, request, **kwargs):
         logging.debug(f"MSApi POST: {request}")
         request = urllib.parse.quote(request)
-        return requests.post(f"{ms_url}/{request}",
-                             headers={"Authorization": f"Bearer {cls.__authorizer.token}",
-                                      "Content-Type": "application/json"},
-                             **kwargs)
+        return cls.__session.post(f"{ms_url}/{request}",
+                                  headers={"Authorization": f"Bearer {cls.__authorizer.token}",
+                                           "Content-Type": "application/json"},
+                                  **kwargs)
 
     @classmethod
     def auch_get(cls, request, **kwargs):
@@ -97,10 +109,10 @@ class MSLowApi:
     def auch_put(cls, request, **kwargs):
         logging.debug(f"MSApi PUT: {request}")
         request = urllib.parse.quote(request)
-        return requests.put(f"{ms_url}/{request}",
-                            headers={"Authorization": f"Bearer {cls.__authorizer.token}",
-                                     "Content-Type": "application/json"},
-                            **kwargs)
+        return cls.__session.put(f"{ms_url}/{request}",
+                                 headers={"Authorization": f"Bearer {cls.__authorizer.token}",
+                                          "Content-Type": "application/json"},
+                                 **kwargs)
 
     @classmethod
     # @check_login
@@ -128,10 +140,10 @@ class MSLowApi:
         if params:
             params_str = f"?{'&'.join(params)}"
 
-        return requests.get(f"{request}{params_str}",
-                            headers={"Authorization": f"Bearer {cls.__authorizer.token}",
-                                     "Content-Type": "application/json"},
-                            **kwargs)
+        return cls.__session.get(f"{request}{params_str}",
+                                 headers={"Authorization": f"Bearer {cls.__authorizer.token}",
+                                          "Content-Type": "application/json"},
+                                 **kwargs)
 
     @classmethod
     def gen_objects(cls, request, obj, limit: int = None, expand: Expand = None, **kwargs):
