@@ -1,6 +1,7 @@
 
-from typing import Optional
-from MSApi import check_init, SubObjectMS, PriceType
+from MSApi.ObjectMS import check_init
+from MSApi.SubObjectMS import SubObjectMS
+from MSApi.PriceType import PriceType
 
 
 class SalePrice(SubObjectMS):
